#
# spec file for package python-sushy
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-sushy
Version:        3.2.0
Release:        bp156.3.1
Summary:        Python library to communicate with Redfish based systems
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/sushy
Source0:        https://files.pythonhosted.org/packages/source/s/sushy/sushy-3.2.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-python-dateutil >= 2.7.0
BuildRequires:  python3-python-subunit
BuildRequires:  python3-reno
BuildRequires:  python3-requests >= 2.14.2
BuildRequires:  python3-setuptools
BuildRequires:  python3-stestr
BuildRequires:  python3-stevedore >= 1.29.0
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
Sushy is a Python library to communicate with `Redfish` based systems.

%package -n python3-sushy
Summary:        Python library to communicate with Redfish based systems
Group:          Development/Languages/Python
Requires:       python3-pbr >= 2.0.0
Requires:       python3-python-dateutil >= 2.7.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-stevedore >= 1.29.0

%description -n python3-sushy
Sushy is a Python library to communicate with `Redfish` based systems.

%package -n python-sushy-doc
Summary:        Documentation for OpenStack sushy
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme

%description -n python-sushy-doc
Sushy is a Python library to communicate with `Redfish` based systems.
This package contains the documentation.

%prep
%autosetup -p1 -n sushy-3.2.0
%py_req_cleanup

%build
%{py3_build}
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
python3 -m stestr.cli run

%files -n python3-sushy
%license LICENSE
%doc AUTHORS ChangeLog README.rst
%{python3_sitelib}/sushy*
%{python3_sitelib}/*.egg-info

%files -n python-sushy-doc
%doc doc/build/html
%license LICENSE

%changelog
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.2.0
  - Add `set_system_boot_options` method
  - Lazily load message registries
  - Ignore failing message registry download
  - Explicitly set ramdisk type
  - Bump hacking to 3.0.0
  - Fix incorrect usage of assertRaisesRegex in unit tests
  - Add `Connector(..., response_callback=None)`` parameter
  - Make MessageRegistryFile.Registry attribute non-required
* Thu Mar 12 2020 cloud-devel@suse.de
- update to version 3.1.0
  - Add ``Endpoint`` sub-resource to ``Fabric``
  - Fix exposed UpdateService constants
  - Enforce running tox with correct python version based on env
  - Fix wrong default JsonDataReader() argument
  - Add conditional field matching
  - Update model to support ApplyTime annotations
  - Add @Redfish.Settings update status and expose it for BIOS
  - Switch jobs to python3
  - Added changes to `simple_update` on update service
  - Retry Virtual Media eject action on HTTP 400 response
  - Add settable `IndicatorLED` of `System` and `Chassis`
  - Add Power and Thermal resources to Chassis
  - update git.openstack.org to opendev
  - OpenDev Migration Patch
  - Add MappedListField
  - Add OEM extension example script
  - Automatically discover available system/manager/chassis
  - Action #Bios.ResetBios fails as POST request has no body
  - Handle incomplete messages in MessageRegistry
  - Relax required Redfish fields handling
  - Update master for stable/train
  - Add versions to release notes series
  - Disregard registry files of unsupported types
  - Disable HTTP connection pooling
  - Change OEM extensions architecture
  - Expand Drive schema
  - Add mappings for `system_type`
  - Update Python 3 test runtimes for Train
  - Add Task Monitor support for async operations
  - Stop using six library
  - Drop python 2.7 support and testing
  - Make UpdateService.simple_update() operational
  - Add settable `IndicatorLED` property to the `Drive` resource
  - Enhance Storage models to support RAID config
  - Update sphinx requirements
  - Cleanup for Standard message registry loading
  - Update master for stable/stein
  - Add support for loading packaged standard registries
  - Dropping the py35 testing
  - Low case `ParamTypes` in received `MessageRegistry`
  - Add public resource loading and message parsing
  - Implements adapter checking
  - Adding Thermal resource schema
  - Add `FabricCollection` and `Fabric` classes
  - Handle incomplete message registries
  - Adding Power resource schema
  - Fix 'None' field value processing
  - Refactor DurableName identifier and Protocol fields
  - Include OData-Version header in Redfish requests
  - Use collections.abc instead of collections when available
  - Cache message registries
  - Build pdf doc
  - Deprecate System-specific `IndicatorLED` state constants
  - Make Manager->Actions field optional
  - Fix typo in the section Enabling SSL
  - Change sushy devstack job to python3
  - SSC.disks_sizes_bytes handle CapacityBytes is None
  - Make message registries available to all resources
  - Unify OEM Actions with non-OEM Actions
* Tue May  7 2019 cloud-devel@suse.de
- update to version 1.8.1
  - Update .gitreview for stable/stein
  - Fix wrong default JsonDataReader() argument
* Mon Mar  4 2019 Colleen Murphy <comurphy@suse.com>
- update to version 1.8.0
  - Add foundation for supporting Redfish OEMs
  - Introduce default value for `transfer_protocol` parameter
  - Add support for ilo Virtual Media
  - Add support for the `CompositionService` resource
  - Add support for the `UpdateService` resource
  - Follow Up Zuulv3
  - Move to zuulv3
  - Introduce `dateutil`
  - Update the docstring of `sub_processors()`
  - Update to public
  - Add missing tests
  - Add Chassis<->ComputerSystem/Manager linkage
  - Add System<->Manager linkage follow up
  - Add System<->Manager linkage
  - Change openstack-dev to openstack-discuss and update URL
  - Add `ChassisCollection` and `Chassis` classes
  - Cleanup JsonDataReader name
  - remove useless whitespces
  - Unify sushy models by Redfish schema bundle
  - Delete HTTP tokens on `Sushy` shutdown
  - [Trivial Fix] modify spelling errors of fulfill, for, containing
  - Change adapter to 'int_or_none' for processor properties
  - [Trivial Fix] modify spelling error of "committed"
  - Add support for loading resources from archive file
  - [Trivial Fix] modify spelling error of "resource"
  - Follow-up to 27c725c to move up ``cache_clear``
  - Requests session keyword arguments for sushy connector
  - Introduce ``cache_it`` and ``cache_clear``
  - Fix crashing `BasicAuth` context manager
  - Remove stray unicode character from tox.ini
  - Add `ProtocolFeaturesSupported` property of the `Root Service`
  - Add product property to the root Sushy object
  - Update to use mapped field for Settings Message Severity field
  - Omit tests from code coverage run
  - Use templates for cover and lower-constraints
  - Return sizes of storage devices
  - Fix for MediaTypes in virtual media
  - Add Message Registry File resource
  - Cleanup names for message registry
  - Add storage and simple_storage attr to system
  - Caching ResourceCollectionBase::get_members()
  - Add a virtual media resource
  - add python 3.6 unit test job
  - switch documentation job to new PTI
  - import zuul job settings from project-config
  - Add system storage resource support
  - Cleanup docstring for removed etag param
  - Add Redfish Message Registry resource
  - Add DictionaryField class to resource base
  - Update reno for stable/rocky
* Tue Sep 11 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid repetition of name in summary (rpmlint).
* Tue Sep 11 2018 cloud-devel@suse.de
- update to version 1.6.0
  - Update reno for stable/queens
  - Switch to use stestr for unit test
  - Add processor ProcessorId field and Status field
  - Hide Attribute Registry property in Bios
  - Add reusable ActionField
  - fix error url
  - Zuul: Remove project name
  - Add system simple storage resource support
  - Cleanup unittest file loading
  - Add storage volume
  - Do not run functional (API) tests in the CI
  - Introduce BIOS API
  - Fix wrong message of invalid boot "enabled" parameter
  - Gate fix: Cap hacking to avoid gate failure
  - Add storage disk drive
  - Replace curly quotes with straight quotes
  - Add system status field
  - Change BootSourceOverrideMode from BIOS to Legacy
  - fix tox python3 overrides
  - tox: Use default Python 3 version, remove pypy
  - Restores sushy session functionality.
  - Remove etag from Bios
  - Mark Systems/Managers/SessionService optional
  - Update Launchpad references to Storyboard
  - Create mappings for System Indicator LED
  - Updated from global requirements
  - add lower-constraints job
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.3.2
  - Updated from global requirements
  - Mark Systems/Managers/SessionService optional
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 1.3.1 (bsc#1078607)
  - Enable some off-by-default checks
  - Add ListField class to resource base
  - Update .gitreview for stable/queens
  - Avoid tox_install.sh for constraints support
  - Replace HTTP numeric constants with http_client constants
  - Add PUT method to connector
  - Restore the default semantics of refresh()
  - Indicating the location tests directory in oslo_debug_helper
  - Zuul: Remove project name
  - flake8: Enable some off-by-default checks
  - Adds EthernetInterface to the library
  - Add int_or_none adapter function
  - zuul: clean up job definition
  - Update documentation related to 'refresh()'
  - Add DELETE method to connector
  - Add Zuul v3 jobs in tree
  - Update UPPER_CONSTRAINTS_FILE for stable/queens
  - Update method docstring
  - Use the tempest plugin from openstack/ironic-tempest-plugin
  - Refining the resource refresh
  - Update some tests to copy the dictionaries passed in
  - Update reno for stable/pike
  - Restores sushy session functionality.
  - Follow-up patch for 8fe2904a62b0f56dc3fc3fefc5a5a746911ce891
  - Restore interface of Connector
  - Implement Redfish Sessions
  - Updated from global requirements
  - Add support to accept custom connector object
* Wed Feb  7 2018 tbechtold@suse.com
- Initial packaging (version 1.1.0)
